@@ -83,6 +83,8 @@ SEXP addVertices_R(SEXP x, SEXP nv, SEXP vattr);
 
 SEXP deleteEdgeAttribute_R(SEXP x, SEXP attrname);
 
+SEXP getEdgeAttribute_R(SEXP el,SEXP attrname, SEXP naomit,SEXP nullna,SEXP deletededgesomit);
+
 SEXP deleteEdges_R(SEXP x, SEXP eid);
 
 SEXP deleteNetworkAttribute_R(SEXP x, SEXP attrname);
@@ -107,10 +109,16 @@ SEXP permuteVertexIDs_R(SEXP x, SEXP vids);
 
 SEXP setEdgeAttribute_R(SEXP x, SEXP attrname, SEXP value, SEXP e);
 
+SEXP setEdgeAttributes_R(SEXP x, SEXP attrname, SEXP value, SEXP e);
+
 SEXP setEdgeValue_R(SEXP x, SEXP attrname, SEXP value, SEXP e);
 
 SEXP setNetworkAttribute_R(SEXP x, SEXP attrname, SEXP value);
 
 SEXP setVertexAttribute_R(SEXP x, SEXP attrname, SEXP value, SEXP v);
 
+SEXP setVertexAttributes_R(SEXP x, SEXP attrname, SEXP value, SEXP v);
+
+SEXP nonEmptyEdges_R(SEXP el);
+
 #endif
