@@ -100,6 +100,18 @@ check[43]<-all(as.sociomatrix(temp,"value")==g*matrix(1:100,10,10))
 temp<-as.network.matrix(as.matrix.network.incidence(temp,"value"),matrix.type="incidence",names.eval="value",ignore.eval=FALSE)
 check[44]<-all(as.sociomatrix(temp,"value")==g*matrix(1:100,10,10))
 
+# check functioning of na.rm argument #922
+plain<-as.network.matrix(matrix(c(0,1,NA,NA),ncol=2),na.rm=TRUE)
+if (network.naedgecount(plain) != 0){
+  stop('problem with na values in adjacency matrix coericon')
+}
+plain<-as.network.matrix(matrix(c(0,1,NA,NA),ncol=2),na.rm=FALSE)
+if (network.naedgecount(plain) != 1){
+  stop('problem with na values in adjacnecy matrix coericon')
+}
+
+
+
 # check creating of network using dataframe with named cols
 edata <-data.frame(
   tails=c(1,2,3),
@@ -124,6 +136,14 @@ if(!all(list.edge.attributes(temp)==c('goodbye','hello','na'))){
 if(!all(temp%e%'goodbye'==c(3,0,2))){
     stop("problem with network edgelist coercion from data frame")
 }   
+# test for as.matrix.network edgelist bug #935
+x <- network.initialize(10)
+add.edge(x,1,2)
+add.edge(x,2,3)
+set.edge.attribute(x,'foo','bar',e=2) # i.e. the edge from 2 to 3
+if (!identical(as.matrix.network.edgelist(x,'foo'),structure(c("1", "2", "2", "3", NA, "bar"), .Dim = 2:3, n = 10, vnames = 1:10))){
+  stop("problem with as.matrix.network.edgelist with attribute and deleted edge")
+}
 
    
 
